<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.wizart.tech/
 * @since      1.0.0
 *
 * @package    Wizart
 * @subpackage Wizart/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wizart
 * @subpackage Wizart/admin
 * @author     Wizart <nikolay.novosad@wizart.tech>
 */
class Wizart_Admin
{
    const WIZART_PAGE_TITLE = 'Wizart Integration Settings';
    const WIZART_MENU_TEXT = 'Wizart Integration';

    private $variables = [
        'wizart_api_token',
        'wizart_homepage_button_text',
        'wizart_homepage_custom_class',
        'wizart_category_button_text',
        'wizart_category_width',
        'wizart_category_height',
        'wizart_category_custom_class',
        'wizart_single_button_text',
        'wizart_single_width',
        'wizart_single_height',
        'wizart_single_custom_class',
        'wizart_integration_method',
        'wizart_cache_lifetime',
        'wizart_context',
        'wizart_homepage_data_element_selector',
        'wizart_homepage_data_insert_element_position',
        'wizart_homepage_data_iframe_element_selector',
        'wizart_homepage_data_insert_iframe_element_position',
        'wizart_category_data_element_selector',
        'wizart_category_data_insert_element_position',
        'wizart_category_data_iframe_element_selector',
        'wizart_category_data_insert_iframe_element_position',
        'wizart_single_data_element_selector',
        'wizart_single_data_insert_element_position',
        'wizart_single_data_iframe_element_selector',
        'wizart_single_data_insert_iframe_element_position',
        'wizart_is_disable_upload_image',
    ];

    private $checkbox_variables = [
        'wizart_integration_method' => 'deployment_kit',
        'wizart_is_disable_upload_image' => '0',
    ];

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * @var WizartCache|null
     */
    protected $cache;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;

        // Add the options page and menu item.
        add_action('admin_menu', array($this, 'wizart_register_admin_menu'));

        add_action('admin_post', array($this, 'wizart_save'));

        $this->cache = WizartCache::instantiate();
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function wizart_enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plugin_Name_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plugin_Name_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wizart-admin.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function wizart_enqueue_scripts()
    {
        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plugin_Name_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plugin_Name_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

//        wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/plugin-name-admin.js', array( 'jquery' ), $this->version, false );

    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     * http://codex.wordpress.org/Administration_Menus
     *
     * @since    1.0.0
     */
    public function wizart_register_admin_menu()
    {
        add_options_page(
            __(self::WIZART_PAGE_TITLE, $this->plugin_name),
            __(self::WIZART_MENU_TEXT, $this->plugin_name),
            'manage_options',
            $this->plugin_name,
            array($this, 'wizart_display_plugin_admin_page')
        );

    }

    /**
     * Render the settings page for this plugin.
     *
     * @since    1.0.0
     */
    public function wizart_display_plugin_admin_page()
    {
        include_once('views/settings.php');
    }

    /**
     * Validates the incoming nonce value, verifies the current user has
     * permission to save the value from the options page and saves the
     * option to the database.
     */
    public function wizart_save()
    {
        // First, validate the nonce and verify the user as permission to save.
        if (!($this->wizart_has_valid_nonce() && current_user_can('manage_options'))) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }

        // If the above are valid, sanitize and save the option.
        foreach ($this->variables as $variable) {
            if (null !== wp_unslash($_POST[$variable])) {
                $value = sanitize_text_field($_POST[$variable]);

                update_option($variable, $value);
            }
        }

        foreach ($this->checkbox_variables as $key => $checkbox_variable) {
            if (!isset($_POST[$key])) {
                $this->wizart_update_option_checkbox($key, $checkbox_variable);
            }
        }

        update_option('wizart_updated_data', true);

        $this->cache->clear();

        $this->wizart_redirect();
    }

    /**
     * Determines if the nonce variable associated with the options page is set
     * and is valid.
     *
     * @return boolean
     */
    private function wizart_has_valid_nonce()
    {
        // If the field isn't even in the $_POST, then it's invalid.
        if (!isset($_POST['wizart_form'])) {
            return false;
        }

        $field = wp_unslash($_POST['wizart_form']);
        $action = 'wizart_settings_save';

        return wp_verify_nonce($field, $action);
    }

    /**
     * Redirect to the page from which we came (which should always be the
     * admin page. If the referred isn't set, then we redirect the user to
     * the login page.
     *
     * @access private
     */
    private function wizart_redirect()
    {
        // To make the Coding Standards happy, we have to initialize this.
        if (!isset($_POST['_wp_http_referer'])) {
            $_POST['_wp_http_referer'] = wp_login_url();
        }

        // Sanitize the value of the $_POST collection for the Coding Standards.
        $url = sanitize_text_field(
            wp_unslash($_POST['_wp_http_referer'])
        );

        // Finally, redirect back to the admin page.
        wp_safe_redirect(urldecode($url));
        exit;
    }

    /**
     *
     * @since 1.0.7
     */
    private function wizart_update_option_checkbox($option, $value)
    {
        update_option($option, $value);
    }
}