<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.wizart.tech/
 * @since      1.0.0
 *
 * @package    Wizart
 * @subpackage Wizart/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Wizart
 * @subpackage Wizart/includes
 * @author     Wizart <nikolay.novosad@wizart.tech>
 */
class Wizart_INIT
{
    const WIZART_ELEMENTOR_FIELD_NAME = 'elementor_cpt_support';
    const WIZART_ELEMENTOR_CPT = 'product';

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Wizart_Loader    $loader    Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $plugin_name    The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $version    The current version of the plugin.
     */
    protected $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct() {
        if ( defined( 'WIZART_PLUGIN_NAME_VERSION' ) ) {
            $this->version = WIZART_PLUGIN_NAME_VERSION;
        } else {
            $this->version = '1.0.0';
        }
        $this->plugin_name = 'wizart';

        $this->wizart_load_dependencies();
        $this->wizart_define_admin_hooks();

        if ($this->wizart_is_exist_api_token()) {
            $this->wizart_define_public_hooks();
        }
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Plugin_Name_Loader. Orchestrates the hooks of the plugin.
     * - Plugin_Name_i18n. Defines internationalization functionality.
     * - Plugin_Name_Admin. Defines all hooks for the admin area.
     * - Plugin_Name_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function wizart_load_dependencies() {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wizart-loader.php';

        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-wizart-admin.php';

        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        if ($this->wizart_is_exist_api_token()) {
            require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-wizart-public.php';
        }

        $this->loader = new Wizart_Loader();

    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function wizart_define_admin_hooks() {

        $plugin_admin = new Wizart_Admin( $this->wizart_get_plugin_name(), $this->wizart_get_version() );

        $this->loader->wizart_add_action( 'admin_enqueue_scripts', $plugin_admin, 'wizart_enqueue_styles' );
        $this->loader->wizart_add_action( 'admin_enqueue_scripts', $plugin_admin, 'wizart_enqueue_scripts' );

    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function wizart_define_public_hooks() {

        $plugin_public = new Wizart_Public( $this->wizart_get_plugin_name(), $this->wizart_get_version() );

        $this->loader->wizart_add_action( 'wp_enqueue_scripts', $plugin_public, 'wizart_enqueue_styles' );
        $this->loader->wizart_add_action( 'wp_enqueue_scripts', $plugin_public, 'wizart_enqueue_scripts' );
        $this->loader->wizart_add_filter( 'script_loader_tag', $plugin_public, 'wizart_script_add_parameters', 10 ,3);

        if ($this->wizart_is_elementor_product()) {
            $this->loader->wizart_add_action('elementor/widget/render_content', $plugin_public, 'wizart_elementor_render_content', 10, 2);
        }

        $this->loader->wizart_add_action('get_footer', $plugin_public, 'wizart_render_floating_button_iframe');

        $this->loader->wizart_add_action( 'woocommerce_product_meta_start', $plugin_public, 'wizart_single_product_page');
        $this->loader->wizart_add_action( 'woocommerce_after_shop_loop_item', $plugin_public, 'wizart_category_page');

        $this->loader->wizart_add_action( 'woocommerce_before_shop_loop', $plugin_public, 'wizart_handler_vendor_codes');

        $this->loader->wizart_add_action( 'script_loader_tag', $plugin_public, 'wizart_add_async_attribute', 10, 2);
        $this->loader->wizart_add_action( 'script_loader_tag', $plugin_public, 'wizart_add_defer_attribute', 10, 2);

        if( wp_doing_ajax() ) {
            $this->loader->wizart_add_action('wp_ajax_wizart_add_to_cart', $plugin_public, 'wizart_add_to_cart');
            $this->loader->wizart_add_action('wp_ajax_nopriv_wizart_add_to_cart', $plugin_public, 'wizart_add_to_cart');

            $this->loader->wizart_add_action('wp_ajax_wizart_remove_from_cart', $plugin_public, 'wizart_remove_from_cart');
            $this->loader->wizart_add_action('wp_ajax_nopriv_wizart_remove_from_cart', $plugin_public, 'wizart_remove_from_cart');

            $this->loader->wizart_add_action('wp_ajax_wizart_get_cart_items', $plugin_public, 'wizart_get_cart_items');
            $this->loader->wizart_add_action('wp_ajax_nopriv_wizart_get_cart_items', $plugin_public, 'wizart_get_cart_items');
        }

        $this->loader->wizart_add_action('wp_enqueue_scripts', $plugin_public, 'wizart_init_ajax_url', 99);

        $this->loader->wizart_add_action('wp_footer', $plugin_public, 'wizart_output_iframe');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function wizart_run() {
        $this->loader->wizart_run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function wizart_get_plugin_name() {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Wizart_Loader    Orchestrates the hooks of the plugin.
     */
    public function wizart_get_loader() {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function wizart_get_version() {
        return $this->version;
    }

    /**
     * Check if exist api token
     *
     * @since  1.0.3
     * @return bool
     */
    private function wizart_is_exist_api_token()
    {
        if (get_option('wizart_api_token')) {
            return true;
        }

        return false;
    }

    /**
     * Check if elementor plugin
     *
     * @since  1.0.3
     * @return bool
     */
    private function wizart_is_elementor_product(): bool
    {
        $cpt_support = get_option(static::WIZART_ELEMENTOR_FIELD_NAME);
        if (is_array($cpt_support)) {
            if (in_array(static::WIZART_ELEMENTOR_CPT, $cpt_support)) {
                return true;
            }
        }

        return false;
    }
}