<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.wizart.tech/
 * @since      1.0.0
 *
 * @package    Wizart
 * @subpackage Wizart/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wizart
 * @subpackage Wizart/admin
 * @author     Wizart <nikolay.novosad@wizart.tech>
 */
class Wizart_Public
{
    const WIZART_BASE_URI_PIM = 'https://pim-client.wizart.tech';
    const WIZART_AVAILABLE_SKU_URI = 'api/articles/available-vendor-codes';

    const WIZART_ENTRY_POINT_SCRIPT_URL = 'https://d35so7k19vd0fx.cloudfront.net/production/integration/entry-point.min.js';
    const WIZART_FLOATING_BUTTON_SCRIPT_URL = 'https://d35so7k19vd0fx.cloudfront.net/production/integration/floating-button.min.js';

    const WIZART_HANDLE_INTEGRATION_SCRIPT = 'wizart-integration-script';
    const WIZART_HANDLE_INTEGRATION_FLOATING_BUTTON_SCRIPT = 'wizart-floating-button-script';
    const WIZART_HANDLE_SET_SHOPPING_CART_STORE = 'wizart-sync-cart_set-shopping-cart-store';
    const WIZART_HANDLE_ADD_SHOPPING_CART_ITEM = 'wizart-sync-cart_add-shopping-cart-item';
    const WIZART_HANDLE_REMOVE_SHOPPING_CART_ITEM = 'wizart-sync-cart_remove-shopping-cart-item';

    const WIZART_HANDLER_ONLOAD_CALLBACK = 'handler_wizart_onload_callback';

    const WIZART_DATA_TITLE_ATTRIBUTE = 'data-title';
    const WIZART_DATA_WIDTH_ATTRIBUTE = 'data-width';
    const WIZART_DATA_HEIGHT_ATTRIBUTE = 'data-height';
    const WIZART_DATA_CLASS_NAME_ATTRIBUTE = 'data-class_name';

    const WIZART_CACHE_NAME = 'wizart_cache_';
    const WIZART_SINGLE_PRODUCT_PAGE_CACHE_NAME = 'single_product_page_';
    const WIZART_DEFAULT_CACHE_LIFETIME = 43200;

    const WIZART_HANDLE_STYLE = 'wizart-public-style';

    const WIZART_IFRAME_DEFAULT_BUTTON_TEXT_HOMEPAGE = 'Try this article!';
    const WIZART_IFRAME_DEFAULT_BUTTON_TEXT_CATEGORY = 'Try it in your room in one click!';
    const WIZART_IFRAME_DEFAULT_BUTTON_TEXT_PRODUCT_PAGE = 'Try it in your room in one click!';

    const WIZART_CATEGORY_PAGE = 'category';
    const WIZART_PRODUCT_PAGE = 'single';

    const WIZART_ELEMENTOR_WIDGET_NAME = 'woocommerce-product-add-to-cart';

    const WIZART_DATA_ELEMENT_SELECTOR = 'data-element-selector';
    const WIZART_DATA_INSERT_ELEMENT_POSITION = 'data-insert-element-position';
    const WIZART_DATA_IFRAME_ELEMENT_SELECTOR = 'data-iframe-element-selector';
    const WIZART_DATA_INSERT_IFRAME_ELEMENT_POSITION = 'data-insert-iframe-element-position';

    const WIZART_IS_DISABLE_UPLOAD_IMAGE_OPTION = 'wizart_is_disable_upload_image';
    const WIZART_DEACTIVATE_CUSTOM_PHOTO_ATTRIBUTE = 'deactivate_custom_photo';

    private $units = [self::WIZART_DATA_WIDTH_ATTRIBUTE, self::WIZART_DATA_HEIGHT_ATTRIBUTE];

    private $deferScripts = [
        self::WIZART_HANDLE_INTEGRATION_FLOATING_BUTTON_SCRIPT,
    ];

    private $asyncScripts = [
    ];

    const WIZART_CONTEXT = 'wizart_context';
    const WIZART_CONTEXT_ATTRIBUTE = 'context';

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * @var WizartCache|null
     */
    protected $cache;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of the plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->cache = WizartCache::instantiate();
    }

    /**
     * Add async attribute
     *
     * @since 1.0.3
     * @param $tag
     * @param $handle
     * @return string|string[]
     */
    public function wizart_add_async_attribute($tag, $handle)
    {
        if (!in_array($handle, $this->asyncScripts)) {
            return $tag;
        }

        return str_replace( ' src', ' async="async" src', $tag );
    }

    /**
     * Add defer attribute
     *
     * @since 1.0.3
     * @param $tag
     * @param $handle
     * @return string|string[]
     */
    public function wizart_add_defer_attribute($tag, $handle)
    {
        if (!in_array($handle, $this->deferScripts)) {
            return $tag;
        }

        return str_replace( ' src', ' defer="defer" src', $tag );
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function wizart_enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plugin_Name_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plugin_Name_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style(self::WIZART_HANDLE_STYLE, plugin_dir_url(__FILE__) . 'css/wizart-public.css', array(), $this->version, 'all');

        if ($this->wizart_is_enable_iframe_integration_method()) {
            wp_enqueue_style(self::WIZART_HANDLE_STYLE . '_iframe', plugin_dir_url(__FILE__) . 'css/wizart-public-iframe.css', array(), $this->version, 'all');
        }
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function wizart_enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Plugin_Name_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Plugin_Name_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script(self::WIZART_HANDLE_ADD_SHOPPING_CART_ITEM, plugin_dir_url(__FILE__) . 'js/sync-cart/add-shopping-cart-item.js', '', $this->version, true);
        wp_enqueue_script(self::WIZART_HANDLE_SET_SHOPPING_CART_STORE, plugin_dir_url(__FILE__) . 'js/sync-cart/set-shopping-cart-store.js', '', $this->version, true);
        wp_enqueue_script(self::WIZART_HANDLE_REMOVE_SHOPPING_CART_ITEM, plugin_dir_url(__FILE__) . 'js/sync-cart/remove-shopping-cart-item.js', '', $this->version, true);

        if (is_front_page() && !$this->wizart_is_enable_iframe_integration_method()) {
            wp_enqueue_script(self::WIZART_HANDLE_INTEGRATION_FLOATING_BUTTON_SCRIPT, self::WIZART_FLOATING_BUTTON_SCRIPT_URL, '', $this->get_js_version(), true);
        }

        if ($this->wizart_is_enable_iframe_integration_method()) {
            wp_enqueue_script(self::WIZART_HANDLE_INTEGRATION_SCRIPT . '_iframe', plugin_dir_url(__FILE__) . 'js/wizart-iframe-integration.js', '', $this->version, true);
            wp_localize_script(self::WIZART_HANDLE_INTEGRATION_SCRIPT . '_iframe', 'wizartData', array(
                'apiToken' => $this->wizart_get_option_value('wizart_api_token'),
                'context' => get_option(static::WIZART_CONTEXT),
            ));
        }
    }

    /**
     * Get js version
     *
     * @since  1.0.3
     * @return false|string
     */
    protected function get_js_version()
    {
        return date('yzH');
    }

    /**
     * Register the woocommerce_after_add_to_cart_form
     *
     * @since  1.0.0
     */
    public function wizart_single_product_page()
    {
        $productSku = $this->wizart_get_sku();

        $cacheKey = static::WIZART_SINGLE_PRODUCT_PAGE_CACHE_NAME . $productSku;
        $content = $this->cache->get($cacheKey);

        if (null !== $content) {
            echo $content;

            return;
        }

        if ($productSku && $this->wizart_available_vendor_codes($productSku)[$productSku]) {
            $content = $this->wizart_render_button($productSku, self::WIZART_PRODUCT_PAGE);
        }

        $this->cache->add($cacheKey, $content ?? '', $this->wizart_get_cache_lifetime());

        echo $content;
    }

    /**
     * Register woocommerce_after_shop_loop_item
     *
     * @since 1.0.0
     */
    public function wizart_category_page()
    {
        if (is_product_category()) {
            $productSku = $this->wizart_get_sku();

            if ($productSku && $this->cache->get($this->wizart_get_cache_name())[$productSku]) {
                $content = $this->wizart_render_button($productSku, self::WIZART_CATEGORY_PAGE);

                echo $content;
            }
        }
    }

    /**
     * Render integration button
     *
     * @param $sku
     * @param $page
     * @return string
     *
     * @since  1.0.0
     */
    public function wizart_render_button($sku, $page): string
    {
        $defaultIframeButtonText = self::WIZART_IFRAME_DEFAULT_BUTTON_TEXT_CATEGORY;
        if ($page === self::WIZART_PRODUCT_PAGE) {
            $defaultIframeButtonText = self::WIZART_IFRAME_DEFAULT_BUTTON_TEXT_PRODUCT_PAGE;
        }

        if (!$this->wizart_is_enable_iframe_integration_method()) {
            $dataToken = $this->wizart_get_option_value('wizart_api_token');
            $entryPointUrl = self::WIZART_ENTRY_POINT_SCRIPT_URL;
            $onloadCallback = self::WIZART_HANDLER_ONLOAD_CALLBACK;
            $buttonTextAttribute = $this->wizart_render_data_attribute('wizart_'. $page .'_button_text', self::WIZART_DATA_TITLE_ATTRIBUTE);
            $widthAttribute = $this->wizart_render_data_attribute('wizart_'. $page .'_width', self::WIZART_DATA_WIDTH_ATTRIBUTE);
            $heightAttribute = $this->wizart_render_data_attribute('wizart_'. $page .'_height', self::WIZART_DATA_HEIGHT_ATTRIBUTE);
            $classNameAttribute = $this->wizart_render_data_attribute('wizart_' . $page .'_custom_class', self::WIZART_DATA_CLASS_NAME_ATTRIBUTE);

            $dataElementSelector = $this->wizart_render_data_attribute('wizart_' . $page .'_data_element_selector', self::WIZART_DATA_ELEMENT_SELECTOR);
            $dataInsertElementPosition = $this->wizart_render_data_attribute('wizart_' . $page .'_data_insert_element_position', self::WIZART_DATA_INSERT_ELEMENT_POSITION);
            $dataIframeElementSelector = $this->wizart_render_data_attribute('wizart_' . $page .'_data_iframe_element_selector', self::WIZART_DATA_IFRAME_ELEMENT_SELECTOR);
            $dataInsertIframeElementPosition = $this->wizart_render_data_attribute('wizart_' . $page .'_data_iframe_element_position', self::WIZART_DATA_INSERT_IFRAME_ELEMENT_POSITION);

            $content = <<<JS
                <script
                        class="wizart__entry-point"
                        data-vendor_code="{$sku}"
                        data-token="{$dataToken}"
                        src="{$entryPointUrl}"
                        data-onload-callback="{$onloadCallback}"
                        data-parameters='{$this->wizart_prepare_data_parameters()}'
                    {$buttonTextAttribute}
                    {$widthAttribute}
                    {$heightAttribute}
                    {$classNameAttribute}
                    {$dataElementSelector}
                    {$dataInsertElementPosition}
                    {$dataIframeElementSelector}
                    {$dataInsertIframeElementPosition}
                ></script>
JS;
        } else {
            $className = esc_html(get_option('wizart_'. $page .'_custom_class'));
            $styleButtonIframe = $this->wizart_render_styles_button_iframe('wizart_' . $page .'_width', 'wizart_'. $page .'_height');
            $buttonText = esc_html(get_option('wizart_'. $page .'_button_text')) ?: $defaultIframeButtonText;
            $pathToSvgFile = file_get_contents(plugin_dir_path(dirname(__FILE__)) . 'public/partials/wizart-public-display-svg.php');

            $content = <<<HTML
                    <button id="wizart-fitting-room-button" class="{$className}"
                            onClick="openSpecificFittingRoom('{$sku}')"
                            style="{$styleButtonIframe}">
                        {$pathToSvgFile}    
                        {$buttonText}
                    </button>
HTML;
        }
        $content .= '<div class="break"></div>';

        return $content;
    }

    /**
     * Changed html code for display floating button
     *
     * @since 1.0.0
     * @param $tag
     * @param $handle
     * @param $src
     * @return string
     */
    public function wizart_script_add_parameters($tag, $handle, $src)
    {
        if (self::WIZART_HANDLE_INTEGRATION_SCRIPT === $handle || self::WIZART_HANDLE_INTEGRATION_FLOATING_BUTTON_SCRIPT === $handle) {
            $tag = '<script 
                       type="text/javascript" 
                       src="' . $src . '" 
                       class="wizart__floating-button" 
                       data-parameters="' .$this->wizart_prepare_data_parameters() .'"
                       data-token="' . $this->wizart_get_option_value('wizart_api_token') . '" 
                       data-onload-callback="' . self::WIZART_HANDLER_ONLOAD_CALLBACK . '"
                       ' . $this->wizart_render_data_attribute('wizart_homepage_button_text', self::WIZART_DATA_TITLE_ATTRIBUTE) . '
                       ' . $this->wizart_render_data_attribute('wizart_homepage_custom_class', self::WIZART_DATA_CLASS_NAME_ATTRIBUTE) . '
                       ' . $this->wizart_render_data_attribute('wizart_homepage_data_element_selector', self::WIZART_DATA_ELEMENT_SELECTOR) . '
                       ' . $this->wizart_render_data_attribute('wizart_homepage_data_insert_element_position', self::WIZART_DATA_INSERT_ELEMENT_POSITION) . '
                       ' . $this->wizart_render_data_attribute('wizart_homepage_data_iframe_element_selector', self::WIZART_DATA_IFRAME_ELEMENT_SELECTOR) . '
                       ' . $this->wizart_render_data_attribute('wizart_homepage_data_insert_iframe_element_position', self::WIZART_DATA_INSERT_IFRAME_ELEMENT_POSITION) . '
                    ></script>';
        }

        return $tag;
    }

    /**
     * Handler vendor codes for category page
     *
     * @since  1.0.0
     * @return bool
     */
    public function wizart_handler_vendor_codes()
    {
        if (is_tax()) {
            $currentObjectRequest = get_queried_object();

            $args = array(
                'post_type' => 'product',
                'posts_per_page' => -1,
                'post_status' => 'publish',
                'tax_query' => array(
                    array(
                        'taxonomy' => $currentObjectRequest->taxonomy,
                        'field' => 'term_id',
                        'terms' => $currentObjectRequest->term_id
                    )
                )
            );

            $query = new WP_Query($args);
            $products = $query->get_posts();

            $vendorCodes = [];
            foreach ($products as $product) {
                $wcProduct = wc_get_product($product->ID);
                $sku = $wcProduct->get_sku();
                if ($sku) {
                    $vendorCodes[] = $sku;
                }
            }

            $vendorCodes = implode(',', $vendorCodes);

            $availableVendorCodes = $this->wizart_available_vendor_codes($vendorCodes);

            if (count($availableVendorCodes) > 0) {
                $this->cache->add($this->wizart_get_cache_name(), $availableVendorCodes, $this->wizart_get_cache_lifetime());

                return true;
            }
        }

        return false;
    }

    /**
     * Check available vendor code for category page
     *
     * @since 1.0.0
     * @param string $vendorCodes
     * @return array
     */
    private function wizart_available_vendor_codes($vendorCodes)
    {
        if (empty($vendorCodes)) {
            return [];
        }

        $url = self::WIZART_BASE_URI_PIM . DIRECTORY_SEPARATOR . self::WIZART_AVAILABLE_SKU_URI;
        $params = [
            'vendor_code' => $vendorCodes,
            'api_token' => $this->wizart_get_option_value('wizart_api_token'),
        ];

        $params = urldecode_deep($params);
        $url = add_query_arg($params, $url);

        $response = wp_remote_get($url);
        $body = wp_remote_retrieve_body($response);
        $body = json_decode($body, true);

        if (!$dataVendorCodes = $body['data']['vendor_codes']) {
            return [];
        }

        return $dataVendorCodes;
    }

    /**
     * Set ajaxurl variable
     *
     * @since  1.0.0
     */
    function wizart_init_ajax_url()
    {
        $handles = [
            self::WIZART_HANDLE_ADD_SHOPPING_CART_ITEM,
            self::WIZART_HANDLE_REMOVE_SHOPPING_CART_ITEM,
            self::WIZART_HANDLE_SET_SHOPPING_CART_STORE,
        ];

        foreach ($handles as $handle) {
            wp_localize_script($handle, 'ajax_url',
                array(
                    'url' => admin_url('admin-ajax.php')
                )
            );
        }

    }

    /**
     * Callback for add product to cart
     *
     * @since  1.0.0
     * @return string
     */
    public function wizart_add_to_cart()
    {
        if (isset($_POST['vendor_code']) && !empty($_POST['vendor_code'])) {
            $sku = htmlspecialchars($_POST['vendor_code']);

            if ($sku) {
                $productId = wc_get_product_id_by_sku($sku);
                try {
                    WC()->cart->add_to_cart($productId);
                } catch (Exception $e) {
                    return $e->getMessage();
                }
            }

            wp_die();
        }
    }

    /**
     * Get all products for cart
     *
     * @since  1.0.0
     * @return void
     */
    public function wizart_get_cart_items()
    {
        $products = [];

        if (WC()->cart->get_cart_contents_count() > 0) {
            foreach (WC()->cart->get_cart() as $item) {
                $product = wc_get_product($item['data']->get_id());
                $products[] = [
                    'vendor_code' => $product->get_sku(),
                    'quantity' => $item['quantity']
                ];
            }
        }

        echo json_encode($products);
        wp_die();
    }

    /**
     * Callback for remove from cart
     *
     * @since  1.0.0
     */
    public function wizart_remove_from_cart()
    {
        if (isset($_POST['vendor_code']) && isset($_POST['remove_all'])) {
            global $wpdb;

            $sku = htmlspecialchars($_POST['vendor_code']);
            $isRemoveAll = filter_var($_POST['remove_all'], FILTER_VALIDATE_BOOLEAN);

            if ($sku) {
                $products = $wpdb->get_results($wpdb->prepare("SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_sku' AND meta_value='%s'", $sku));
                $productsId = [];

                foreach ($products as $product) {
                    $productsId[] = $product->post_id;
                }

                foreach (WC()->cart->get_cart() as $cartItemKey => $cartItem) {
                    $productId = $cartItem['data']->get_id();

                    if (in_array($productId, $productsId)) {
                        if ($isRemoveAll) {
                            WC()->cart->remove_cart_item($cartItemKey);
                        } else {
                            $quantity = (int)$cartItem['quantity'] - 1;
                            if ($quantity === 0) {
                                WC()->cart->remove_cart_item($cartItemKey);
                            } else {
                                WC()->cart->set_quantity($cartItemKey, $quantity);
                            }
                        }
                    }
                }
            }
        }

        wp_die();
    }

    /**
     * Get api token
     *
     * @since  1.0.0
     * @param string $option_key
     * @return mixed|void
     */
    private function wizart_get_option_value($option_key)
    {
        return get_option($option_key);
    }

    /**
     * Return script attribute from admin panel
     *
     * @since  1.0.0
     * @param string $option_key
     * @param string $attribute
     * @return bool|string
     */
    private function wizart_render_data_attribute($option_key, $attribute)
    {
        if ($value = $this->wizart_get_option_value($option_key)) {
            return $attribute . ' = "' . esc_html($value) . '" ';
        }

        return false;
    }

    /**
     * @since  1.0.0
     * @param string $value
     * @return bool|string
     */
    private function wizart_check_unit_attribute($value)
    {
        if (in_array($value, $this->units)) {
            return 'px';
        }

        return false;
    }

    /**
     * Get cache name for available vendor codes
     *
     * @since  1.0.2
     * @return string
     */
    private function wizart_get_cache_name()
    {
        $currentObjectRequest = get_queried_object();

        return self::WIZART_CACHE_NAME . $currentObjectRequest->taxonomy . '_' . $currentObjectRequest->term_id;
    }

    /**
     * Check if integration via iframe
     *
     * @since  1.0.2
     * @return bool
     */
    private function wizart_is_enable_iframe_integration_method()
    {
        return ('iframe' === $this->wizart_get_option_value('wizart_integration_method'));
    }

    /**
     * Display iframe
     *
     * @since  1.0.2
     */
    public function wizart_output_iframe()
    {
        if ($this->wizart_is_enable_iframe_integration_method()) {
            require_once plugin_dir_path(dirname(__FILE__)) . 'public/partials/wizart-public-display-iframe.php';
        }
    }

    /**
     * Render styles for button if iframe integration
     *
     * @since  1.0.2
     * @param $width_key
     * @param $height_key
     * @return string|null
     */
    public function wizart_render_styles_button_iframe($width_key, $height_key)
    {
        $styles = null;

        if ($width = $this->wizart_get_option_value($width_key)) {
            $styles = 'width: ' . $width . ';';
        }

        if ($height = $this->wizart_get_option_value($height_key)) {
            $styles .= 'height: ' . $height . ';';
        }

        return $styles;
    }

    /**
     * Get life time for cache
     *
     * @since  1.0.3
     * @return int
     */
    private function wizart_get_cache_lifetime()
    {
        return get_option('wizart_cache_lifetime') ? : static::WIZART_DEFAULT_CACHE_LIFETIME;
    }

    /**
     * Render content for elementor plugin
     *
     * @since  1.0.3
     * @param $content
     * @param $widget
     * @return mixed|string
     */
    public function wizart_elementor_render_content($content, $widget): string
    {
        if ($widget->get_name() === static::WIZART_ELEMENTOR_WIDGET_NAME) {
            $content .= '<br/>'.$this->wizart_render_button($this->wizart_get_sku(), self::WIZART_PRODUCT_PAGE);
        }

        return $content;
    }

    /**
     * Get product sku
     *
     * @since  1.0.3
     * @return string
     */
    private function wizart_get_sku(): string
    {
        global $product;

        return $product->get_sku();
    }

    /**
     * Display render floating button for iframe method
     *
     * @since  1.0.4
     */
    public function wizart_render_floating_button_iframe()
    {
        if (is_front_page() && $this->wizart_is_enable_iframe_integration_method()) {
            $defaultIframeButtonText = self::WIZART_IFRAME_DEFAULT_BUTTON_TEXT_HOMEPAGE;

            $className = esc_html(get_option('wizart_homepage_custom_class'));
            $buttonText = esc_html(get_option('wizart_homepage_button_text')) ?: $defaultIframeButtonText;
            $pathToSvgFile = file_get_contents(plugin_dir_path(dirname(__FILE__)) . 'public/partials/wizart-public-display-iframe-svg.php');

            echo <<<HTML
                    <div class="wizart-fitting-room__iframe--floating">
                    <button id="wizart-fitting-room-button" class="wizart-fitting-room-button_homepage__iframe--floating {$className}"
                            onClick="openFittingRoom()">
                            {$pathToSvgFile}
                            {$buttonText}
                    </button>
                    </div>
HTML;
        }
    }

    /**
     * Prepare data for data parameters attribute
     *
     * @since  1.0.5
     */
    private function wizart_prepare_data_parameters()
    {
        $dataAttributeValue = "";

        $dataAttributeValueContext = [];
        $dataAttributeValueDisableUploadImage = [];

        if (get_option(static::WIZART_CONTEXT)) {
            $dataAttributeValueContext = array(static::WIZART_CONTEXT_ATTRIBUTE => get_option(static::WIZART_CONTEXT));
        }

        if (get_option(static::WIZART_IS_DISABLE_UPLOAD_IMAGE_OPTION) === '1') {
            $dataAttributeValueDisableUploadImage = array(static::WIZART_DEACTIVATE_CUSTOM_PHOTO_ATTRIBUTE => get_option(static::WIZART_IS_DISABLE_UPLOAD_IMAGE_OPTION));
        }

        if ($this->wizart_is_exist_data_parameter($dataAttributeValueContext) || $this->wizart_is_exist_data_parameter($dataAttributeValueDisableUploadImage)) {
            $dataAttributeValue = array_merge($dataAttributeValueContext, $dataAttributeValueDisableUploadImage);
            $dataAttributeValue = htmlspecialchars(json_encode($dataAttributeValue));
        }

        return $dataAttributeValue;
    }

    /**
     *
     * @since 1.0.7
     */
    private function wizart_is_exist_data_parameter($data)
    {
        return count($data) > 0;
    }
}